@@ -49,6 +49,17 @@ public:
   MessageTextField(QWidget* parent = 0);
   ~MessageTextField();
 
+  enum DisplayMode
+  {
+    StandardDisplayMode,
+    PlatformDisplayMode // This has only effect on Maemo where the control tries to look
+                        // like the text field in the conversations application
+  };
+
+  /// Get/Set the display mode
+  void setDisplayMode(DisplayMode displayMode);
+  DisplayMode displayMode() const;
+
   /// Get/Set the codec for this field (for future use)
   //void setCodec(QTextCodec* codec);
   //QTextCodec* codec() const;
@@ -65,4 +76,6 @@ private:
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
 
+Q_DECLARE_METATYPE(MessageTextField::DisplayMode)
+
 #endif // MESSAGETEXTFIELD_HPP
