@@ -24,6 +24,7 @@
 
 // Local includes
 #include "providers/providerinterface.hpp"
+#include "settings.hpp"
 
 // Forward declarations
 class MessageWidgetPrivate;
@@ -48,6 +49,10 @@ public:
   void setCurrentMessageType(const MessageType& messageType);
   MessageType currentMessageType() const;
 
+  /// Get/Set the settings (may be removed here)
+  void setSettings(const Settings& settings);
+  Settings settings() const;
+
 protected:
   MessageWidgetPrivate* d;
 };
