@@ -352,6 +352,19 @@ ProviderInfo Accounts::providerInfoForAlias(const QString& alias) const
   return ProviderInfo();
 }
 
+//////////////////////////////////////////////////////////////////////////
+
+ProviderInfo Accounts::providerInfoForProvider(ProviderInterface* provider) const
+{
+  // Find the alias (could be done faster but I'm lazy ..)
+  QString alias = d->aliasToProvider.key(provider);
+  if ( !alias.isNull() )
+    return providerInfoForAlias(alias);
+
+  // Nothing found :(
+  return ProviderInfo();
+}
+
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////
