@@ -105,7 +105,7 @@ void AccountsDialogPrivate::onNewButtonClicked()
     return;
 
   // Create a temporary config which will be added
-  AccountConfig config(dialog.alias(), dialog.providerInfo().providerId);
+  AccountConfig config(dialog.alias(), dialog.providerInfo().providerId());
   accounts->addAccount(config);
 
   // Get the provider interface
@@ -174,6 +174,20 @@ AccountsDialog::~AccountsDialog()
 
 //////////////////////////////////////////////////////////////////////////
 
+void AccountsDialog::setCurrentAccount(const QString& alias)
+{
+  // TODO: Implementation
+}
+
+//////////////////////////////////////////////////////////////////////////
+
+QString AccountsDialog::currentAccount() const
+{
+  return d->ui.listView->currentIndex().data(AccountsModel::AccountAliasRole).toString();
+}
+
+//////////////////////////////////////////////////////////////////////////
+
 void AccountsDialog::setAccounts(const AccountsPtr& accounts)
 {
   // Something changed?
