@@ -30,7 +30,8 @@
 //////////////////////////////////////////////////////////////////////////
 
 /// Convert a phone number to international format
-bool PROVIDERS_API make_number_international(QString& number);
+bool PROVIDERS_API isInternationalNumber(const QString& number);
+bool PROVIDERS_API make_number_international(const QString& prefix, QString* number, bool* wasPrefixed);
 
 extern "C"
 {
