@@ -93,17 +93,30 @@ int PROVIDERS_API get_contact_for_sms(const struct QString* dialogTitle, struct
 
   if ( selection )
   {
-    EVCardAttribute* selectedAttribute;
+    EVCardAttribute* selectedAttribute = NULL;
+    GtkWidget* numberChooser = NULL;
 
-    // Show a new dialog where the user chooses a phone number
-    GtkWidget* numberChooser;
-    numberChooser = osso_abook_contact_detail_selector_new_for_contact(NULL, selection->data, OSSO_ABOOK_CONTACT_DETAIL_PHONE);
+    OssoABookContactDetailStore* detailStore = osso_abook_contact_detail_store_new(selection->data, OSSO_ABOOK_CONTACT_DETAIL_SMS);
+    GSequence* sequence = osso_abook_contact_detail_store_get_fields(detailStore);
 
-    gtk_dialog_run(GTK_DIALOG(numberChooser));
-    gtk_widget_hide(numberChooser);
+    gint fieldCount = g_sequence_get_length(sequence);
+    if ( fieldCount > 1 )
+    {
+      // Show a new dialog where the user chooses a phone number
+      numberChooser = osso_abook_contact_detail_selector_new_for_contact(NULL, selection->data, OSSO_ABOOK_CONTACT_DETAIL_SMS);
+
+      gtk_dialog_run(GTK_DIALOG(numberChooser));
+      gtk_widget_hide(numberChooser);
+
+      // Get the selected attribute
+      selectedAttribute = osso_abook_contact_detail_selector_get_detail(OSSO_ABOOK_CONTACT_DETAIL_SELECTOR(numberChooser));
+    }
+    else if ( fieldCount == 1 )
+    {
+      GSequenceIter* iter = g_sequence_get_begin_iter(sequence);
+      selectedAttribute = osso_abook_contact_field_get_attribute( g_sequence_get(iter) );
+    }
 
-    // Get the selected attribute
-    selectedAttribute = osso_abook_contact_detail_selector_get_detail(OSSO_ABOOK_CONTACT_DETAIL_SELECTOR(numberChooser));
     if ( selectedAttribute )
     {
       ContactInfoList_addContact(contacts,
@@ -111,11 +124,17 @@ int PROVIDERS_API get_contact_for_sms(const struct QString* dialogTitle, struct
                                  e_vcard_attribute_get_value(selectedAttribute), // Get the number of the contact
                                  e_contact_get_const(E_CONTACT(selection->data), E_CONTACT_UID)); // Get the uid of the contact
 
+      g_printf("Contact chosen: %s (%s)\n",
+               osso_abook_contact_get_display_name(selection->data),
+               e_vcard_attribute_get_value(selectedAttribute));
+
       success = TRUE;
     }
 
     // Destroy the number chooser
-    gtk_widget_destroy(numberChooser);
+    if ( numberChooser )
+      gtk_widget_destroy(numberChooser);
+    g_object_unref(detailStore);
   }
 
   // Free some memory
