@@ -214,7 +214,7 @@ void Innosend::sendMessage(const Message& message)
   // Fix for numbers. This provider doesn't like the "+" sign, so we replace it by "00"
   number.replace(QRegExp("^\\+"), "00");
 
-  QByteArray text = toUrlPercentEncoding( message.text().toLocal8Bit() );
+  QByteArray text = toUrlPercentEncoding( toLatin1Euro(message.text()) );
 
   // Setup the message
   QUrl url("https://www.innosend.de/gateway/sms.php");
