@@ -54,10 +54,6 @@ public:
     urls.smsCenterSendUrl = QUrl("https://email.o2online.de/smscenter_send.osp");
     urls.comCenterUrl     = QUrl("https://email.o2online.de/ssomanager.osp?APIID=AUTH-WEBSSO&TargetApp=m_folder_detail.osp%3FFolder%3DO3sis%3A%3AInbox");
 
-    // Read the settings
-    //loginName = settings.value("loginName").toString();
-    //password  = settings.value("password").toString();
-
     connect(&accessManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(onReplyFinished(QNetworkReply*)));
   }
 
@@ -315,6 +311,17 @@ void o2GermanyPrivate::handleSmsCenterSend(QNetworkReply* reply)
 
   // Emit a signal that we've sent the message
   emit self->sendMessageReply(true, message);
+
+  // We dome some dummy analysis of the message ...
+  MessageType messageType = message.messageType();
+  QString messageText = message.text();
+
+  int usedMessageCount = (messageText.size() / messageType.singleMessageLength()) + 1;
+
+  // Subtract ...
+  freeSMSCount -= usedMessageCount;
+
+  emit self->balanceReply( tr("%n* free SMS", "", freeSMSCount) );
 }
 
 //////////////////////////////////////////////////////////////////////////
